@@ -18,7 +18,7 @@ class WaylandConfig;
 class WaylandBackend : public KScreen::AbstractBackend
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA(IID "org.kf5.kscreen.backends.kwayland")
+    Q_PLUGIN_METADATA(IID "org.kf6.kscreen.backends.kwayland")
 
 public:
     explicit WaylandBackend();
@@ -27,7 +27,7 @@ public:
     QString name() const override;
     QString serviceName() const override;
     KScreen::ConfigPtr config() const override;
-    void setConfig(const KScreen::ConfigPtr &config) override;
+    QString setConfig(const KScreen::ConfigPtr &config) override;
     bool isValid() const override;
     QByteArray edid(int outputId) const override;
 
