@@ -197,37 +197,32 @@ void WaylandConfig::addOutput(quint32 name, quint32 version)
     auto device = new WaylandOutputDevice(++s_outputId);
     m_initializingOutputs << device;
 
-    connect(this, &WaylandConfig::globalRemoved, this, [name, device, this](const uint32_t &interfaceName) {
+    connect(this, &WaylandConfig::globalRemoved, device, [name, device, this](const uint32_t &interfaceName) {
         if (name == interfaceName) {
             removeOutput(device);
         }
     });
 
-    QMetaObject::Connection *const connection = new QMetaObject::Connection;
-    *connection = connect(device, &WaylandOutputDevice::done, this, [this, connection, device]() {
-        QObject::disconnect(*connection);
-        delete connection;
+    connect(device, &WaylandOutputDevice::done, this, [this, device]() {
+        if (m_initializingOutputs.removeOne(device)) {
+            m_outputMap.insert(device->id(), device);
+            if (m_outputOrder) {
+                device->setIndex(m_outputOrder->order().indexOf(device->name()) + 1);
+            }
+            checkInitialized();
 
-        m_initializingOutputs.removeOne(device);
-        m_outputMap.insert(device->id(), device);
-        if (m_outputOrder) {
-            device->setIndex(m_outputOrder->order().indexOf(device->name()) + 1);
-        }
-        checkInitialized();
-
-        if (m_initializingOutputs.isEmpty()) {
-            m_screen->setOutputs(m_outputMap.values());
-        }
-        if (!m_blockSignals && m_initializingOutputs.isEmpty()) {
-            Q_EMIT configChanged();
-        }
-
-        connect(device, &WaylandOutputDevice::done, this, [this]() {
+            if (m_initializingOutputs.isEmpty()) {
+                m_screen->setOutputs(m_outputMap.values());
+            }
+            if (!m_blockSignals && m_initializingOutputs.isEmpty()) {
+                Q_EMIT configChanged();
+            }
+        } else {
             // output got update must update current config
             if (!m_blockSignals) {
                 Q_EMIT configChanged();
             }
-        });
+        }
     });
 
     device->init(m_registry, name, version);
@@ -343,7 +338,19 @@ WaylandOutputDevice *WaylandConfig::findOutputDevice(struct ::kde_output_device_
 
 bool WaylandConfig::applyConfig(const KScreen::ConfigPtr &newConfig)
 {
+    for (const auto &output : newConfig->outputs()) {
+        if (!m_outputMap.contains(output->id())) {
+            qCWarning(KSCREEN_WAYLAND) << "Cannot find output with id" << output->id();
+            return false;
+        }
+    }
+
     newConfig->adjustPriorities(); // never trust input
+    if (m_blockSignals) {
+        // Last apply still pending, remember new changes and apply afterwards
+        m_kscreenPendingConfig = newConfig;
+        return true;
+    }
 
     // Create a new configuration object
     auto wlConfig = m_outputManagement->createConfiguration();
@@ -352,17 +359,12 @@ bool WaylandConfig::applyConfig(const KScreen::ConfigPtr &newConfig)
     }
     bool changed = false;
 
-    if (m_blockSignals) {
-        // Last apply still pending, remember new changes and apply afterwards
-        m_kscreenPendingConfig = newConfig;
-        return true;
-    }
-
     for (const auto &output : newConfig->outputs()) {
         changed |= m_outputMap[output->id()]->setWlConfig(wlConfig, output);
     }
 
     if (!changed) {
+        delete wlConfig;
         return false;
     }
 
