@@ -53,13 +53,7 @@ void WaylandOutputDevice::kde_output_device_v2_geometry(int32_t x,
 
 void WaylandOutputDevice::kde_output_device_v2_current_mode(struct ::kde_output_device_mode_v2 *mode)
 {
-    auto m = WaylandOutputDeviceMode::get(mode);
-
-    if (*m == *m_mode) {
-        // unchanged
-        return;
-    }
-    m_mode = m;
+    m_mode = WaylandOutputDeviceMode::get(mode);
 }
 
 void WaylandOutputDevice::kde_output_device_v2_mode(struct ::kde_output_device_mode_v2 *mode)
@@ -144,30 +138,26 @@ void KScreen::WaylandOutputDevice::updateKScreenModes(OutputPtr &output)
 {
     ModeList modeList;
     QStringList preferredModeIds;
-    QString currentModeId = QStringLiteral("-1");
-    int modeId = 0;
+    QString currentModeId;
 
     for (const WaylandOutputDeviceMode *wlMode : std::as_const(m_modes)) {
         ModePtr mode(new Mode());
 
-        const QString modeIdStr = QString::number(modeId);
-        // KWayland gives the refresh rate as int in mHz
-        mode->setId(modeIdStr);
-        mode->setRefreshRate(wlMode->refreshRate() / 1000.0);
+        mode->setId(wlMode->id());
+        mode->setRefreshRate(wlMode->refreshRate());
         mode->setSize(wlMode->size());
         mode->setName(modeName(wlMode));
 
         if (m_mode == wlMode) {
-            currentModeId = modeIdStr;
+            currentModeId = wlMode->id();
         }
 
         if (wlMode->preferred()) {
-            preferredModeIds << modeIdStr;
+            preferredModeIds << wlMode->id();
         }
 
         // Add to the modelist which gets set on the output
-        modeList[modeIdStr] = mode;
-        modeId++;
+        modeList[wlMode->id()] = mode;
     }
     output->setCurrentModeId(currentModeId);
     output->setPreferredModes(preferredModeIds);
@@ -181,6 +171,8 @@ void WaylandOutputDevice::updateKScreenOutput(OutputPtr &output)
     output->setEnabled(enabled());
     output->setConnected(true);
     output->setName(name());
+    output->setVendor(m_manufacturer);
+    output->setModel(m_model);
     output->setSizeMm(m_physicalSize);
     output->setPos(m_pos);
     output->setRotation(toKScreenRotation(m_transform));
@@ -210,18 +202,25 @@ void WaylandOutputDevice::updateKScreenOutput(OutputPtr &output)
     output->setMinBrightnessOverride(m_minBrightnessOverride);
     output->setColorProfileSource(static_cast<Output::ColorProfileSource>(m_colorProfileSource));
     output->setBrightness(m_brightness / 10'000.0);
+    output->setColorPowerPreference(static_cast<Output::ColorPowerTradeoff>(m_colorPowerPreference));
+    output->setDimming(m_dimming / 10'000.0);
 
     updateKScreenModes(output);
 }
 
 QString WaylandOutputDevice::modeId() const
 {
-    return QString::number(m_modes.indexOf(m_mode));
+    return m_mode->id();
 }
 
-WaylandOutputDeviceMode *WaylandOutputDevice::deviceModeFromId(const int modeId) const
+WaylandOutputDeviceMode *WaylandOutputDevice::deviceModeFromId(const QString &id) const
 {
-    return m_modes.at(modeId);
+    for (WaylandOutputDeviceMode *mode : m_modes) {
+        if (mode->id() == id) {
+            return mode;
+        }
+    }
+    return nullptr;
 }
 
 bool WaylandOutputDevice::setWlConfig(WaylandOutputConfiguration *wlConfig, const KScreen::OutputPtr &output)
@@ -254,13 +253,9 @@ bool WaylandOutputDevice::setWlConfig(WaylandOutputConfiguration *wlConfig, cons
 
     // mode
     const ModePtr mode = output->currentMode();
-    if (mode->size() != pixelSize() || mode->refreshRate() != refreshRate()) {
-        bool toIntOk;
-        int modeId = mode->id().toInt(&toIntOk);
-        Q_ASSERT(toIntOk);
-
+    if (mode->id() != modeId()) {
         changed = true;
-        wlConfig->mode(object(), deviceModeFromId(modeId)->object());
+        wlConfig->mode(object(), deviceModeFromId(mode->id())->object());
     }
 
     // overscan
@@ -329,6 +324,15 @@ bool WaylandOutputDevice::setWlConfig(WaylandOutputConfiguration *wlConfig, cons
         wlConfig->set_brightness(object(), std::round(output->brightness() * 10'000));
         changed = true;
     }
+    if (version >= KDE_OUTPUT_CONFIGURATION_V2_SET_COLOR_POWER_TRADEOFF_SINCE_VERSION
+        && m_colorPowerPreference != static_cast<color_power_tradeoff>(output->colorPowerPreference())) {
+        wlConfig->set_color_power_tradeoff(object(), static_cast<color_power_tradeoff>(output->colorPowerPreference()));
+        changed = true;
+    }
+    if (version >= KDE_OUTPUT_CONFIGURATION_V2_SET_DIMMING_SINCE_VERSION && m_dimming != uint32_t(std::round(output->dimming() * 10'000))) {
+        wlConfig->set_dimming(object(), std::round(output->dimming() * 10'000));
+        changed = true;
+    }
 
     return changed;
 }
@@ -336,7 +340,7 @@ bool WaylandOutputDevice::setWlConfig(WaylandOutputConfiguration *wlConfig, cons
 QString WaylandOutputDevice::modeName(const WaylandOutputDeviceMode *m) const
 {
     return QString::number(m->size().width()) + QLatin1Char('x') + QString::number(m->size().height()) + QLatin1Char('@')
-        + QString::number(qRound(m->refreshRate() / 1000.0));
+        + QString::number(qRound(m->refreshRate()));
 }
 
 QString WaylandOutputDevice::name() const
@@ -487,6 +491,16 @@ void WaylandOutputDevice::kde_output_device_v2_brightness(uint32_t brightness)
     m_brightness = brightness;
 }
 
+void WaylandOutputDevice::kde_output_device_v2_color_power_tradeoff(uint32_t preference)
+{
+    m_colorPowerPreference = static_cast<color_power_tradeoff>(preference);
+}
+
+void WaylandOutputDevice::kde_output_device_v2_dimming(uint32_t dimming)
+{
+    m_dimming = dimming;
+}
+
 QByteArray WaylandOutputDevice::edid() const
 {
     return m_edid;
@@ -527,7 +541,7 @@ QSize WaylandOutputDevice::pixelSize() const
     return m_mode->size();
 }
 
-int WaylandOutputDevice::refreshRate() const
+float WaylandOutputDevice::refreshRate() const
 {
     return m_mode->refreshRate();
 }
