@@ -9,11 +9,7 @@
 #include "../xcbwrapper.h"
 
 #include <QGuiApplication>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
+#include <QtGui/private/qtx11extras_p.h>
 
 Q_LOGGING_CATEGORY(KSCREEN_XCB_HELPER, "kscreen.xcb.helper")
 
@@ -111,11 +107,7 @@ QString XCBEventListener::connectionToString(xcb_randr_connection_t connection)
     return QStringLiteral("invalid value (%1)").arg(connection);
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-bool XCBEventListener::nativeEventFilter(const QByteArray &eventType, void *message, long int *result)
-#else
 bool XCBEventListener::nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result)
-#endif
 {
     Q_UNUSED(result);
 
@@ -195,7 +187,9 @@ void XCBEventListener::handleXRandRNotify(xcb_generic_event_t *e)
         qCDebug(KSCREEN_XCB_HELPER) << "RRNotify_OutputProperty (ignored)";
         qCDebug(KSCREEN_XCB_HELPER) << "\tTimestamp: " << property.timestamp;
         qCDebug(KSCREEN_XCB_HELPER) << "\tOutput: " << property.output;
-        qCDebug(KSCREEN_XCB_HELPER) << "\tProperty: " << xcb_get_atom_name_name(reply.data());
+        qCDebug(KSCREEN_XCB_HELPER) << "\tProperty: " << QByteArray::fromRawData(xcb_get_atom_name_name(reply.data()), xcb_get_atom_name_name_length(reply.data()));
         qCDebug(KSCREEN_XCB_HELPER) << "\tState (newValue, Deleted): " << property.status;
     }
 }
+
+#include "moc_xcbeventlistener.cpp"
