@@ -130,3 +130,7 @@ KScreen::AbstractBackend *ConfigOperationPrivate::loadBackend()
     }
     return backend;
 }
+
+#include "moc_configoperation.cpp"
+
+#include "moc_configoperation_p.cpp"
