@@ -3,10 +3,11 @@
 //
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
-#include "kscreendpms_debug.h"
 #include "waylanddpmshelper_p.h"
 
-#include "qwayland-dpms.h"
+#include <kscreendpms_debug.h>
+#include <qwayland-dpms.h>
+
 #include <QDebug>
 #include <QGuiApplication>
 #include <QList>
@@ -15,7 +16,6 @@
 #include <QWaylandClientExtensionTemplate>
 #include <qpa/qplatformscreen_p.h>
 
-
 class Dpms : public QObject, public QtWayland::org_kde_kwin_dpms
 {
 public:
