@@ -41,6 +41,8 @@ public:
     Private(const Private &other)
         : id(other.id)
         , name(other.name)
+        , vendor(other.vendor)
+        , model(other.model)
         , type(other.type)
         , icon(other.icon)
         , pos(other.pos)
@@ -74,6 +76,10 @@ public:
         , maxPeakBrightnessOverride(other.maxPeakBrightnessOverride)
         , maxAverageBrightnessOverride(other.maxAverageBrightnessOverride)
         , minBrightnessOverride(other.minBrightnessOverride)
+        , colorProfileSource(other.colorProfileSource)
+        , brightness(other.brightness)
+        , colorPowerPreference(other.colorPowerPreference)
+        , dimming(other.dimming)
     {
         const auto otherModeList = other.modeList;
         for (const ModePtr &otherMode : otherModeList) {
@@ -90,6 +96,8 @@ public:
     // please keep them consistent with order of Q_PROPERTY declarations
     int id;
     QString name;
+    QString vendor;
+    QString model;
     Type type;
     QString icon;
     ModeList modeList;
@@ -127,6 +135,10 @@ public:
     std::optional<double> maxPeakBrightnessOverride;
     std::optional<double> maxAverageBrightnessOverride;
     std::optional<double> minBrightnessOverride;
+    ColorProfileSource colorProfileSource = ColorProfileSource::sRGB;
+    double brightness = 1.0;
+    ColorPowerTradeoff colorPowerPreference = ColorPowerTradeoff::PreferEfficiency;
+    double dimming = 1.0;
 };
 
 bool Output::Private::compareModeList(const ModeList &before, const ModeList &after)
@@ -237,6 +249,34 @@ void Output::setName(const QString &name)
     Q_EMIT outputChanged();
 }
 
+QString Output::vendor() const
+{
+    return d->vendor;
+}
+
+void Output::setVendor(const QString &vendor)
+{
+    if (d->vendor == vendor) {
+        return;
+    }
+    d->vendor = vendor;
+    Q_EMIT vendorChanged();
+}
+
+QString Output::model() const
+{
+    return d->model;
+}
+
+void Output::setModel(const QString &model)
+{
+    if (d->model == model) {
+        return;
+    }
+    d->model = model;
+    Q_EMIT modelChanged();
+}
+
 // TODO KF6: remove this deprecated method
 QString Output::hash() const
 {
@@ -580,6 +620,12 @@ void Output::setEdid(const QByteArray &rawData)
 {
     Q_ASSERT(d->edid.isNull());
     d->edid.reset(new Edid(rawData));
+    if (d->vendor.isEmpty()) {
+        setVendor(d->edid->vendor());
+    }
+    if (d->model.isEmpty()) {
+        setModel(d->edid->name());
+    }
 }
 
 Edid *Output::edid() const
@@ -850,6 +896,58 @@ void Output::setMinBrightnessOverride(std::optional<double> value)
     }
 }
 
+Output::ColorProfileSource Output::colorProfileSource() const
+{
+    return d->colorProfileSource;
+}
+
+void Output::setColorProfileSource(ColorProfileSource source)
+{
+    if (d->colorProfileSource != source) {
+        d->colorProfileSource = source;
+        Q_EMIT colorProfileSourceChanged();
+    }
+}
+
+double Output::brightness() const
+{
+    return d->brightness;
+}
+
+void Output::setBrightness(double brightness)
+{
+    if (d->brightness != brightness) {
+        d->brightness = brightness;
+        Q_EMIT brightnessChanged();
+    }
+}
+
+Output::ColorPowerTradeoff Output::colorPowerPreference() const
+{
+    return d->colorPowerPreference;
+}
+
+void Output::setColorPowerPreference(ColorPowerTradeoff tradeoff)
+{
+    if (d->colorPowerPreference != tradeoff) {
+        d->colorPowerPreference = tradeoff;
+        Q_EMIT colorPowerPreferenceChanged();
+    }
+}
+
+double Output::dimming() const
+{
+    return d->dimming;
+}
+
+void Output::setDimming(double dimming)
+{
+    if (d->dimming != dimming) {
+        d->dimming = dimming;
+        Q_EMIT dimmingChanged();
+    }
+}
+
 void Output::apply(const OutputPtr &other)
 {
     typedef void (KScreen::Output::*ChangeSignal)();
@@ -984,6 +1082,22 @@ void Output::apply(const OutputPtr &other)
         changes << &Output::minBrightnessOverrideChanged;
         setMinBrightnessOverride(other->d->minBrightnessOverride);
     }
+    if (d->colorProfileSource != other->d->colorProfileSource) {
+        changes << &Output::colorProfileSourceChanged;
+        setColorProfileSource(other->d->colorProfileSource);
+    }
+    if (d->brightness != other->d->brightness) {
+        changes << &Output::brightnessChanged;
+        setBrightness(other->d->brightness);
+    }
+    if (d->colorPowerPreference != other->d->colorPowerPreference) {
+        changes << &Output::colorPowerPreferenceChanged;
+        setColorPowerPreference(other->d->colorPowerPreference);
+    }
+    if (d->dimming != other->d->dimming) {
+        changes << &Output::dimmingChanged;
+        setDimming(other->d->dimming);
+    }
 
     // Non-notifyable changes
     if (other->d->edid) {
