@@ -30,6 +30,8 @@ class KSCREEN_EXPORT Output : public QObject
 public:
     Q_PROPERTY(int id READ id CONSTANT)
     Q_PROPERTY(QString name READ name WRITE setName NOTIFY outputChanged)
+    Q_PROPERTY(QString vendor READ vendor WRITE setVendor NOTIFY vendorChanged)
+    Q_PROPERTY(QString model READ model WRITE setModel NOTIFY modelChanged)
     Q_PROPERTY(Type type READ type WRITE setType NOTIFY outputChanged)
     Q_PROPERTY(QString icon READ icon WRITE setIcon NOTIFY outputChanged)
     Q_PROPERTY(ModeList modes READ modes NOTIFY modesChanged)
@@ -60,6 +62,8 @@ public:
     Q_PROPERTY(QString iccProfilePath READ iccProfilePath WRITE setIccProfilePath NOTIFY iccProfilePathChanged)
     Q_PROPERTY(ColorProfileSource colorProfileSource READ colorProfileSource WRITE setColorProfileSource NOTIFY colorProfileSourceChanged)
     Q_PROPERTY(double brightness READ brightness WRITE setBrightness NOTIFY brightnessChanged)
+    Q_PROPERTY(ColorPowerTradeoff colorPowerPreference READ colorPowerPreference WRITE setColorPowerPreference NOTIFY colorPowerPreferenceChanged)
+    Q_PROPERTY(double dimming READ dimming WRITE setDimming NOTIFY dimmingChanged)
 
     enum Type {
         Unknown,
@@ -134,6 +138,12 @@ public:
     };
     Q_ENUM(ColorProfileSource)
 
+    enum class ColorPowerTradeoff {
+        PreferEfficiency = 0,
+        PreferAccuracy = 1,
+    };
+    Q_ENUM(ColorPowerTradeoff)
+
     explicit Output();
     ~Output() override;
 
@@ -145,6 +155,12 @@ public:
     QString name() const;
     void setName(const QString &name);
 
+    QString vendor() const;
+    void setVendor(const QString &vendor);
+
+    QString model() const;
+    void setModel(const QString &model);
+
     /**
      * Returns an identifying hash for this output.
      *
@@ -527,6 +543,12 @@ public:
     double brightness() const;
     void setBrightness(double brightness);
 
+    ColorPowerTradeoff colorPowerPreference() const;
+    void setColorPowerPreference(ColorPowerTradeoff tradeoff);
+
+    double dimming() const;
+    void setDimming(double dimming);
+
     void apply(const OutputPtr &other);
 
 Q_SIGNALS:
@@ -561,6 +583,10 @@ Q_SIGNALS:
     void minBrightnessOverrideChanged();
     void colorProfileSourceChanged();
     void brightnessChanged();
+    void vendorChanged();
+    void modelChanged();
+    void colorPowerPreferenceChanged();
+    void dimmingChanged();
 
     /** The mode list changed.
      *
